# satellites-client
https://docs.google.com/document/d/1zCe6QAhIFP7SfXc-88Kr_ypZGeJsAqaRJpXmxAOZhUs/edit

## Installation
### Composer
Ajouter les modules communs dans composer.json
```json
{
    "repositories": [{
            "type": "composer",
            "url": "https://git.nwb.fr/api/packages/modules-communs-php/composer"
        }
    ]
}
```
Lancer la commande
```bash
composer require nwb/satellites-client
```
### Env
La classe utilise ces env en priorité
```dotenv
SAT_USER
SAT_PWD
SAT_API_KEY
```
Si ces env ne sont pas définis, la classe utilise les env suivants
```dotenv
SAT_LOGIN
SAT_MDP
SAT_APIKEY
```

Il est possible de surcharger les env via le constructeur
```php
use Nwb\Satellites\SatelliteClient;

$satelliteClient = new SatelliteClient('user', 'password', 'apiKey');
```

## Utilisation

### Uploader un fichier
```php
use Nwb\Satellites\File;
use Nwb\Satellites\SatelliteClient;

$file = File::createFromPath(__DIR__ . '/assets/img/1.jpg');
(new SatelliteClient())->uploadFile($file);
```

### Supprimer un fichier
```php
use Nwb\Satellites\SatelliteClient;
use Nwb\Satellites\File;

$file = (new File())
    ->setSatelliteId(1)
    ->setHash('hash')
    ->setSize(123);

(new SatelliteClient())->deleteFile($file);
```

### Télécharger un fichier sur le disque (stream)
```php
use Nwb\Satellites\SatelliteClient;
use Nwb\Satellites\File;

$file = (new File())
    ->setSatelliteId(1)
    ->setHash('hash')
    ->setSize(123);

(new SatelliteClient())->downloadFileTo($file, '/path/to/file');
```

### Télécharger un fichier en mémoire
```php
use Nwb\Satellites\SatelliteClient;
use Nwb\Satellites\File;

$file = (new File())
    ->setSatelliteId(1)
    ->setHash('hash')
    ->setSize(123);

$content = (new SatelliteClient())->downloadFileAsString($file);

file_put_contents('path', $content);
```

### Obtenir le lien d'un fichier
```php
use Nwb\Satellites\SatelliteClient;
use Nwb\Satellites\File;

$file = (new File())
    ->setSatelliteId(1)
    ->setHash('hash')
    ->setSize(123);

$url = (new SatelliteClient())->getFileUrl($file);
```

### Télécharger une miniature
```php
use Nwb\Satellites\SatelliteClient;
use Nwb\Satellites\File;

$file = (new File())
    ->setHash('hash')
    ->setSatelliteId(1)
    ->setSize(123);

$content = (new SatelliteClient())->downloadThumbnail($file);

file_put_contents('path', $content);
```

### Obtenir le lien d'une miniature
```php
use Nwb\Satellites\SatelliteClient;
use Nwb\Satellites\File;

$file = (new File())
    ->setSatelliteId(1)
    ->setHash('hash')
    ->setSize(123);

$url = (new SatelliteClient())->getThumbnailUrl($file);
```

### Obtenir les métadonnées d'une image
```php
use Nwb\Satellites\SatelliteClient;
use Nwb\Satellites\File;

$file = (new File())
    ->setSatelliteId(1)
    ->setHash('hash')
    ->setSize(123);

$meta = (new SatelliteClient())->getMetaImage($file);
```

## Tests
```bash
./vendor/bin/phpunit
```
