<?php

namespace Nwb\Satellites;

class SatelliteMapper
{
    private const URL_MAP = 'https://www.nowwweb.com/fichiers/map_satellites.json';

    private static array $cache;

    private function parseMap(string $satelliteMap): array
    {
        $satellitesStatus = json_decode(
            json_decode($satelliteMap, true, 512, JSON_THROW_ON_ERROR)['m_sJsonOuXml_etat'],
            true,
            512,
            JSON_THROW_ON_ERROR
        );

        return array_map(fn (array $satellite) => $this->arrayToSatellite($satellite), $satellitesStatus);
    }

    private function arrayToSatellite(array $array): Satellite
    {
        return (new Satellite())
            ->setDomain($array['sDomaine'])
            ->setIsOnline($array['bEnLigne'])
            ->setIsAcceptingFiles($array['bAccepte_fichier'])
            ->setAvailableSpace($array['nEspace_libre'])
            ->setAvailableSpaceForUpload($array['nEspace_libre_pour_envoi_fichier']);
    }

    private function list(): array
    {
        if (isset(self::$cache)) {
            return self::$cache;
        }

        $httpClient = new HttpClient();

        $satelliteMap = $httpClient->request(self::URL_MAP, [
            CURLOPT_RETURNTRANSFER => true,
        ]);

        return self::$cache = $this->parseMap($satelliteMap);
    }

    public function chooseSatelliteForUpload(int $filesize): Satellite
    {
        $availableSatellites = array_filter(
            $this->list(),
            fn (Satellite $satellite) =>
            $satellite->getIsOnline()
                && $satellite->getIsAcceptingFiles()
                && $filesize < $satellite->getAvailableSpaceForUpload()
        );

        return $availableSatellites[array_rand($availableSatellites)];
    }
}
